import os

from plzz.helper_functions.helper_functions import colors


def create_lorem_ipsum_file(filename, num_lines):
    """
    Creates a Lorem Ipsum file with a specified number of lines.
    
    Parameters:
    filename (str): The name of the output file.
    num_lines (int): The number of lines to generate.
    
    Returns:
    None
    
    Raises:
    ValueError: If the number of lines is not a positive integer.
    """
    # Validate the parameter
    if not isinstance(num_lines, int) or num_lines <= 0:
        print("{}{}ERROR: Number of lines must be at least 1!{}".format(
            colors.BOLD,
            colors.FAIL,
            colors.ENDC
        ))
        return
        # raise ValueError("The number of lines must be a positive integer.")

    if os.path.exists(filename):
        print("{}{}ERROR: File '{}' already exists!{}".format(
            colors.BOLD,
            colors.FAIL,
            filename,
            colors.ENDC
        ))

        return
    
    # Define the Lorem Ipsum text
    lorem_ipsum = """Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Purus non enim praesent elementum facilisis leo. In egestas erat imperdiet sed euismod nisi porta. Duis at consectetur lorem donec massa sapien faucibus et molestie. Nullam eget felis eget nunc. Tristique sollicitudin nibh sit amet commodo nulla facilisi. Dolor magna eget est lorem. At quis risus sed vulputate odio ut enim blandit volutpat. Egestas sed sed risus pretium quam vulputate dignissim. Viverra nibh cras pulvinar mattis nunc sed blandit libero.

In nibh mauris cursus mattis molestie a iaculis at. Quis ipsum suspendisse ultrices gravida dictum fusce ut. Lobortis feugiat vivamus at augue eget arcu dictum varius duis. Amet mattis vulputate enim nulla aliquet porttitor lacus. At in tellus integer feugiat scelerisque varius. Nibh mauris cursus mattis molestie a iaculis at erat pellentesque. Eu lobortis elementum nibh tellus molestie nunc non. Bibendum ut tristique et egestas quis ipsum. Rhoncus mattis rhoncus urna neque viverra justo nec. Duis ultricies lacus sed turpis tincidunt id aliquet risus. At volutpat diam ut venenatis. Dignissim convallis aenean et tortor at risus viverra adipiscing. Phasellus vestibulum lorem sed risus ultricies. Interdum velit laoreet id donec ultrices. Feugiat in ante metus dictum at tempor. Amet purus gravida quis blandit turpis cursus in.

Sed velit dignissim sodales ut eu sem integer vitae justo. Phasellus vestibulum lorem sed risus ultricies tristique nulla. Egestas pretium aenean pharetra magna ac placerat vestibulum. Enim ut tellus elementum sagittis vitae et. Eget mauris pharetra et ultrices neque ornare aenean. Fermentum iaculis eu non diam phasellus vestibulum lorem sed. Ac placerat vestibulum lectus mauris ultrices. Diam vulputate ut pharetra sit amet. Nec tincidunt praesent semper feugiat nibh sed pulvinar proin gravida. Ante in nibh mauris cursus mattis molestie a. Feugiat pretium nibh ipsum consequat nisl vel.

Sagittis aliquam malesuada bibendum arcu vitae elementum curabitur vitae. Velit laoreet id donec ultrices tincidunt arcu non. Dictumst quisque sagittis purus sit amet volutpat consequat. Eget gravida cum sociis natoque penatibus et magnis dis. A arcu cursus vitae congue mauris rhoncus aenean. Magnis dis parturient montes nascetur ridiculus mus. Massa enim nec dui nunc mattis enim ut tellus elementum. Sapien eget mi proin sed libero enim. Sem nulla pharetra diam sit amet nisl suscipit. Auctor eu augue ut lectus arcu bibendum at. Dignissim diam quis enim lobortis scelerisque fermentum.

Integer quis auctor elit sed. Id semper risus in hendrerit gravida rutrum quisque. Scelerisque viverra mauris in aliquam sem. Non sodales neque sodales ut etiam. Pellentesque diam volutpat commodo sed. Aliquam malesuada bibendum arcu vitae elementum curabitur vitae nunc. Et magnis dis parturient montes. Ridiculus mus mauris vitae ultricies leo integer malesuada. Donec adipiscing tristique risus nec feugiat in fermentum. Felis eget velit aliquet sagittis id consectetur purus. Volutpat est velit egestas dui id ornare arcu odio ut. Mattis nunc sed blandit libero volutpat sed cras. Facilisi nullam vehicula ipsum a arcu cursus vitae congue. Tincidunt vitae semper quis lectus nulla at volutpat diam ut.

Euismod elementum nisi quis eleifend quam adipiscing. Vestibulum mattis ullamcorper velit sed ullamcorper morbi tincidunt ornare. Sem viverra aliquet eget sit. Quis blandit turpis cursus in. Libero nunc consequat interdum varius sit amet mattis vulputate enim. Vitae tortor condimentum lacinia quis vel eros donec. Ut diam quam nulla porttitor massa. Pharetra magna ac placerat vestibulum lectus mauris ultrices eros in. Pellentesque id nibh tortor id aliquet. Auctor augue mauris augue neque gravida in fermentum et sollicitudin. Vitae turpis massa sed elementum. Ultricies lacus sed turpis tincidunt. Cras semper auctor neque vitae tempus quam pellentesque. Elementum pulvinar etiam non quam lacus suspendisse faucibus interdum. Tincidunt lobortis feugiat vivamus at augue eget arcu. Id velit ut tortor pretium viverra. Commodo nulla facilisi nullam vehicula ipsum. Faucibus pulvinar elementum integer enim. Amet aliquam id diam maecenas ultricies mi eget mauris pharetra.

Nec ullamcorper sit amet risus nullam. Feugiat vivamus at augue eget arcu dictum varius. Hac habitasse platea dictumst quisque sagittis purus sit. Sed nisi lacus sed viverra tellus in hac habitasse. Enim sit amet venenatis urna. Augue interdum velit euismod in pellentesque massa placerat. Eget gravida cum sociis natoque penatibus et. Bibendum est ultricies integer quis auctor elit sed. Egestas tellus rutrum tellus pellentesque eu tincidunt tortor aliquam nulla. Pharetra sit amet aliquam id diam. Eget duis at tellus at urna. Viverra ipsum nunc aliquet bibendum enim. At lectus urna duis convallis convallis tellus id. Quisque egestas diam in arcu cursus. Proin sed libero enim sed faucibus turpis in. Urna neque viverra justo nec ultrices dui sapien. Scelerisque in dictum non consectetur a erat nam at lectus. At consectetur lorem donec massa sapien faucibus et.

Tellus molestie nunc non blandit massa enim nec dui nunc. Urna id volutpat lacus laoreet non curabitur gravida arcu ac. Lectus arcu bibendum at varius vel. Faucibus a pellentesque sit amet porttitor eget dolor morbi non. Id porta nibh venenatis cras sed felis eget. Habitant morbi tristique senectus et netus. Morbi non arcu risus quis varius quam quisque id. Facilisis magna etiam tempor orci eu. Dignissim convallis aenean et tortor at risus viverra adipiscing. Duis ut diam quam nulla porttitor massa id neque.

Et ultrices neque ornare aenean. Id consectetur purus ut faucibus pulvinar elementum integer enim. Blandit aliquam etiam erat velit scelerisque in dictum non consectetur. Amet massa vitae tortor condimentum lacinia quis vel. Lobortis elementum nibh tellus molestie nunc non blandit massa enim. Consectetur adipiscing elit duis tristique sollicitudin. Dui sapien eget mi proin sed libero enim sed. Sed viverra ipsum nunc aliquet bibendum. Risus commodo viverra maecenas accumsan lacus vel. Pellentesque dignissim enim sit amet venenatis urna cursus eget nunc. Est ultricies integer quis auctor elit. Sed enim ut sem viverra aliquet eget sit amet. Vitae ultricies leo integer malesuada nunc vel risus commodo. Tellus elementum sagittis vitae et leo duis ut diam quam. Facilisis volutpat est velit egestas dui.

Posuere ac ut consequat semper viverra nam. Bibendum neque egestas congue quisque egestas. Vestibulum rhoncus est pellentesque elit ullamcorper dignissim. Facilisi nullam vehicula ipsum a arcu cursus vitae. Et malesuada fames ac turpis egestas sed. Pulvinar etiam non quam lacus suspendisse faucibus interdum posuere lorem. Urna et pharetra pharetra massa massa. Mauris vitae ultricies leo integer malesuada. Aliquet porttitor lacus luctus accumsan. Erat pellentesque adipiscing commodo elit at imperdiet dui accumsan sit. Duis ut diam quam nulla porttitor massa. Mauris ultrices eros in cursus turpis massa tincidunt. Id cursus metus aliquam eleifend mi in. A iaculis at erat pellentesque. Mattis aliquam faucibus purus in massa. Posuere urna nec tincidunt praesent semper feugiat nibh. Turpis egestas integer eget aliquet nibh praesent tristique. Viverra orci sagittis eu volutpat odio facilisis mauris sit. Orci ac auctor augue mauris. Urna neque viverra justo nec ultrices dui sapien.

Nisl nisi scelerisque eu ultrices vitae auctor. Arcu dui vivamus arcu felis bibendum ut. At ultrices mi tempus imperdiet nulla malesuada. Nisl vel pretium lectus quam id leo in vitae turpis. Nibh sit amet commodo nulla facilisi nullam. Consequat ac felis donec et odio pellentesque diam. Mauris ultrices eros in cursus turpis. Eget velit aliquet sagittis id consectetur purus ut faucibus. Nunc sed augue lacus viverra vitae congue eu. Dui sapien eget mi proin sed libero enim sed faucibus. Luctus accumsan tortor posuere ac ut consequat semper. Ornare aenean euismod elementum nisi. In aliquam sem fringilla ut morbi tincidunt augue. Eget duis at tellus at urna condimentum. Quam elementum pulvinar etiam non. Venenatis cras sed felis eget velit. Nisi porta lorem mollis aliquam ut porttitor leo a diam. Mauris pharetra et ultrices neque ornare aenean euismod elementum nisi. Lacus suspendisse faucibus interdum posuere lorem ipsum dolor sit amet. Est ullamcorper eget nulla facilisi etiam dignissim diam quis enim.

Elementum pulvinar etiam non quam lacus suspendisse. Morbi non arcu risus quis. Vel eros donec ac odio. Cursus mattis molestie a iaculis. Congue eu consequat ac felis donec et odio pellentesque diam. Elit ullamcorper dignissim cras tincidunt lobortis feugiat vivamus at augue. Consectetur libero id faucibus nisl. Viverra nibh cras pulvinar mattis nunc sed blandit libero. Libero enim sed faucibus turpis in eu mi. Ultricies integer quis auctor elit sed vulputate mi sit amet. Non consectetur a erat nam at.

Etiam tempor orci eu lobortis elementum. Accumsan sit amet nulla facilisi morbi. Est sit amet facilisis magna etiam tempor orci eu lobortis. Sit amet volutpat consequat mauris nunc congue nisi vitae suscipit. Id diam maecenas ultricies mi eget. Mattis ullamcorper velit sed ullamcorper. Sit amet nulla facilisi morbi tempus iaculis urna id volutpat. Venenatis a condimentum vitae sapien pellentesque. Luctus venenatis lectus magna fringilla urna porttitor rhoncus. Ut diam quam nulla porttitor massa id neque aliquam vestibulum. Tempus quam pellentesque nec nam aliquam sem et tortor consequat. Cras semper auctor neque vitae tempus. Mauris in aliquam sem fringilla ut morbi. Tortor vitae purus faucibus ornare suspendisse. Imperdiet dui accumsan sit amet nulla. Est sit amet facilisis magna etiam tempor orci eu. Ultricies leo integer malesuada nunc. Ut tortor pretium viverra suspendisse potenti nullam ac tortor.

Varius duis at consectetur lorem donec. Odio pellentesque diam volutpat commodo sed. Ut sem nulla pharetra diam. Eu feugiat pretium nibh ipsum consequat nisl. Phasellus egestas tellus rutrum tellus pellentesque eu. Amet dictum sit amet justo donec enim. Quam pellentesque nec nam aliquam sem et tortor consequat id. Sit amet est placerat in egestas erat imperdiet sed euismod. Sollicitudin nibh sit amet commodo nulla facilisi nullam vehicula. Vel elit scelerisque mauris pellentesque pulvinar pellentesque habitant. Neque convallis a cras semper. Tincidunt ornare massa eget egestas purus viverra. Turpis in eu mi bibendum neque. Egestas sed tempus urna et pharetra pharetra. Elementum eu facilisis sed odio morbi quis commodo. Montes nascetur ridiculus mus mauris vitae ultricies. Vitae tempus quam pellentesque nec nam aliquam sem et. Proin gravida hendrerit lectus a. Tempor id eu nisl nunc mi ipsum faucibus. Mi tempus imperdiet nulla malesuada pellentesque elit eget gravida.

Nibh tellus molestie nunc non blandit massa enim nec. Ac tortor dignissim convallis aenean et. Elit sed vulputate mi sit amet mauris commodo quis imperdiet. Ut sem nulla pharetra diam sit amet nisl suscipit. In fermentum et sollicitudin ac. At urna condimentum mattis pellentesque id nibh tortor. Donec massa sapien faucibus et molestie ac feugiat. Pretium vulputate sapien nec sagittis aliquam malesuada bibendum. Mi ipsum faucibus vitae aliquet nec ullamcorper sit. Habitasse platea dictumst quisque sagittis purus sit amet. Gravida arcu ac tortor dignissim convallis aenean.

Elit scelerisque mauris pellentesque pulvinar pellentesque. Elit ullamcorper dignissim cras tincidunt lobortis feugiat vivamus at augue. Pellentesque dignissim enim sit amet venenatis. Elit scelerisque mauris pellentesque pulvinar pellentesque habitant morbi tristique senectus. A condimentum vitae sapien pellentesque. Purus viverra accumsan in nisl nisi. Nunc pulvinar sapien et ligula ullamcorper malesuada proin. Imperdiet proin fermentum leo vel orci. Lobortis feugiat vivamus at augue. Eros in cursus turpis massa tincidunt dui. Volutpat commodo sed egestas egestas fringilla phasellus faucibus.

Malesuada pellentesque elit eget gravida cum sociis natoque. Faucibus vitae aliquet nec ullamcorper sit amet risus nullam. Posuere lorem ipsum dolor sit amet consectetur. Sed arcu non odio euismod lacinia at quis risus sed. Placerat in egestas erat imperdiet sed euismod nisi porta lorem. Ullamcorper velit sed ullamcorper morbi. Eget mi proin sed libero enim. Consectetur adipiscing elit duis tristique sollicitudin nibh sit amet. Lacinia at quis risus sed vulputate odio ut enim. Amet risus nullam eget felis eget nunc lobortis mattis aliquam. Id aliquet lectus proin nibh nisl condimentum. Fusce ut placerat orci nulla pellentesque. Commodo sed egestas egestas fringilla phasellus faucibus scelerisque.

Enim nec dui nunc mattis enim. Parturient montes nascetur ridiculus mus mauris. Nunc congue nisi vitae suscipit tellus mauris. Porta non pulvinar neque laoreet suspendisse interdum consectetur libero id. Fringilla ut morbi tincidunt augue interdum velit euismod. A lacus vestibulum sed arcu non odio euismod lacinia. Sed risus pretium quam vulputate. Sagittis purus sit amet volutpat consequat mauris nunc. Gravida in fermentum et sollicitudin ac orci phasellus egestas tellus. Nisi vitae suscipit tellus mauris a diam maecenas. Et netus et malesuada fames ac turpis egestas integer eget. Aliquet lectus proin nibh nisl condimentum.

A lacus vestibulum sed arcu non odio euismod. In nisl nisi scelerisque eu ultrices vitae auctor. Viverra orci sagittis eu volutpat odio facilisis mauris sit amet. Pellentesque diam volutpat commodo sed. Integer enim neque volutpat ac tincidunt vitae semper quis lectus. Eu augue ut lectus arcu bibendum at varius vel pharetra. Sollicitudin tempor id eu nisl nunc mi. At tellus at urna condimentum mattis. Pulvinar elementum integer enim neque volutpat ac tincidunt vitae semper. Laoreet sit amet cursus sit amet dictum sit amet. Lorem donec massa sapien faucibus et molestie ac feugiat. Nulla facilisi morbi tempus iaculis urna id. Ornare lectus sit amet est placerat in egestas. Ultricies tristique nulla aliquet enim tortor at auctor urna nunc.

Mauris ultrices eros in cursus turpis massa tincidunt dui ut. Scelerisque eleifend donec pretium vulputate sapien nec sagittis aliquam malesuada. Odio morbi quis commodo odio aenean sed. Auctor augue mauris augue neque. Elementum eu facilisis sed odio. Elementum curabitur vitae nunc sed velit dignissim sodales. Risus nec feugiat in fermentum posuere urna nec. Viverra accumsan in nisl nisi scelerisque eu ultrices. Scelerisque viverra mauris in aliquam sem. Luctus accumsan tortor posuere ac ut consequat semper viverra. Sit amet dictum sit amet. Diam sit amet nisl suscipit adipiscing bibendum. Odio pellentesque diam volutpat commodo sed egestas egestas. Risus feugiat in ante metus. Amet massa vitae tortor condimentum lacinia quis. Volutpat lacus laoreet non curabitur. Auctor eu augue ut lectus arcu bibendum at varius vel. Pellentesque sit amet porttitor eget dolor morbi non arcu risus. Pellentesque dignissim enim sit amet venenatis urna.

Scelerisque eu ultrices vitae auctor eu augue ut lectus. Faucibus scelerisque eleifend donec pretium. Potenti nullam ac tortor vitae. Phasellus faucibus scelerisque eleifend donec pretium. Suspendisse interdum consectetur libero id faucibus nisl tincidunt. Est velit egestas dui id ornare arcu odio. Adipiscing bibendum est ultricies integer quis auctor. Arcu dui vivamus arcu felis bibendum ut tristique. Quam id leo in vitae. Pellentesque pulvinar pellentesque habitant morbi tristique senectus et. Vitae tempus quam pellentesque nec nam aliquam. At ultrices mi tempus imperdiet nulla malesuada pellentesque elit. Nibh venenatis cras sed felis eget velit. Ut sem viverra aliquet eget sit amet. Pellentesque id nibh tortor id aliquet lectus. Elit at imperdiet dui accumsan sit amet nulla facilisi morbi. Eget egestas purus viverra accumsan. Donec pretium vulputate sapien nec sagittis aliquam malesuada bibendum arcu. Nunc non blandit massa enim. Dis parturient montes nascetur ridiculus mus.

Duis at consectetur lorem donec massa. Eget magna fermentum iaculis eu non diam phasellus. Mi tempus imperdiet nulla malesuada. Metus dictum at tempor commodo ullamcorper a lacus vestibulum sed. Aenean vel elit scelerisque mauris pellentesque. At elementum eu facilisis sed odio. Auctor elit sed vulputate mi sit amet mauris commodo quis. Diam phasellus vestibulum lorem sed risus. Dolor morbi non arcu risus quis varius quam quisque. Urna et pharetra pharetra massa. Sapien eget mi proin sed libero enim sed faucibus turpis. Mattis vulputate enim nulla aliquet porttitor lacus luctus accumsan. Et netus et malesuada fames. Vel pretium lectus quam id leo in vitae turpis. Semper eget duis at tellus at urna condimentum. Integer vitae justo eget magna fermentum iaculis. Cursus turpis massa tincidunt dui ut ornare. Aliquam sem fringilla ut morbi tincidunt augue interdum. Magna fermentum iaculis eu non diam phasellus vestibulum.

Quis ipsum suspendisse ultrices gravida dictum fusce ut placerat orci. Vitae tortor condimentum lacinia quis vel eros donec ac odio. Sed nisi lacus sed viverra tellus. Fermentum et sollicitudin ac orci phasellus. Sed adipiscing diam donec adipiscing tristique risus nec. Massa sed elementum tempus egestas sed sed. Scelerisque varius morbi enim nunc. Pharetra vel turpis nunc eget lorem dolor sed viverra ipsum. Dignissim diam quis enim lobortis. Rhoncus est pellentesque elit ullamcorper dignissim cras tincidunt lobortis. Erat imperdiet sed euismod nisi porta. Sed nisi lacus sed viverra tellus in hac habitasse platea.

Volutpat diam ut venenatis tellus in metus. Tellus pellentesque eu tincidunt tortor aliquam nulla facilisi. Volutpat consequat mauris nunc congue nisi vitae suscipit tellus mauris. In eu mi bibendum neque egestas. Non consectetur a erat nam at. Neque viverra justo nec ultrices dui sapien eget mi proin. Quis auctor elit sed vulputate mi. Commodo ullamcorper a lacus vestibulum sed arcu non odio. Morbi tempus iaculis urna id volutpat lacus laoreet non curabitur. In iaculis nunc sed augue lacus viverra. Nisi porta lorem mollis aliquam. Neque egestas congue quisque egestas diam in arcu. Mauris pharetra et ultrices neque.

Convallis tellus id interdum velit laoreet. Tristique sollicitudin nibh sit amet commodo nulla facilisi nullam vehicula. Aliquam id diam maecenas ultricies mi eget. Pellentesque id nibh tortor id aliquet lectus proin. Cras fermentum odio eu feugiat pretium nibh ipsum consequat. Convallis aenean et tortor at. Pellentesque elit eget gravida cum. Molestie nunc non blandit massa. Cras semper auctor neque vitae tempus quam pellentesque nec nam. Tortor at auctor urna nunc id. Et sollicitudin ac orci phasellus egestas. Enim sed faucibus turpis in. Urna et pharetra pharetra massa massa. Vitae turpis massa sed elementum tempus egestas sed sed risus. Vel quam elementum pulvinar etiam non quam.

Facilisi cras fermentum odio eu feugiat pretium nibh. Ac tincidunt vitae semper quis lectus nulla at volutpat. Ultrices gravida dictum fusce ut placerat orci nulla pellentesque dignissim. Amet cursus sit amet dictum. Consectetur adipiscing elit ut aliquam purus. Vitae et leo duis ut. Posuere morbi leo urna molestie at elementum eu. Viverra maecenas accumsan lacus vel facilisis volutpat est. Scelerisque varius morbi enim nunc. Morbi tincidunt ornare massa eget egestas purus viverra accumsan. Morbi tristique senectus et netus et. Neque volutpat ac tincidunt vitae semper quis lectus nulla. Nulla posuere sollicitudin aliquam ultrices sagittis orci a scelerisque purus. Arcu odio ut sem nulla pharetra diam sit amet nisl. Fermentum et sollicitudin ac orci phasellus egestas tellus rutrum tellus. Sit amet mauris commodo quis imperdiet massa tincidunt nunc. Habitant morbi tristique senectus et netus et malesuada. Diam quis enim lobortis scelerisque fermentum dui. Et sollicitudin ac orci phasellus egestas.

Id donec ultrices tincidunt arcu non sodales neque sodales ut. Id venenatis a condimentum vitae sapien pellentesque habitant morbi. Convallis tellus id interdum velit laoreet id donec. Sed lectus vestibulum mattis ullamcorper velit. Turpis egestas integer eget aliquet nibh praesent tristique. Pellentesque pulvinar pellentesque habitant morbi tristique senectus et netus. Turpis egestas pretium aenean pharetra magna ac placerat. Risus commodo viverra maecenas accumsan lacus vel. Lorem ipsum dolor sit amet. Sollicitudin nibh sit amet commodo nulla facilisi. Adipiscing tristique risus nec feugiat in fermentum posuere urna. Tempus imperdiet nulla malesuada pellentesque elit eget gravida. Egestas pretium aenean pharetra magna ac. Et ultrices neque ornare aenean euismod elementum. Mauris pellentesque pulvinar pellentesque habitant morbi tristique senectus. Vestibulum mattis ullamcorper velit sed ullamcorper morbi tincidunt.

Integer vitae justo eget magna. Rhoncus mattis rhoncus urna neque viverra justo. Nunc sed blandit libero volutpat sed cras ornare arcu dui. Sed viverra tellus in hac habitasse. Aliquam nulla facilisi cras fermentum odio eu. Vel eros donec ac odio tempor orci dapibus ultrices in. Imperdiet dui accumsan sit amet. Pretium fusce id velit ut tortor. Elementum tempus egestas sed sed risus pretium quam vulputate dignissim. Consequat mauris nunc congue nisi vitae suscipit. Sit amet mauris commodo quis imperdiet massa tincidunt nunc pulvinar. Aliquam ut porttitor leo a diam sollicitudin tempor id eu. Leo duis ut diam quam nulla porttitor massa id neque. Lorem ipsum dolor sit amet consectetur. Dis parturient montes nascetur ridiculus mus. Ridiculus mus mauris vitae ultricies leo integer malesuada nunc vel. Augue lacus viverra vitae congue eu consequat ac. Ac turpis egestas sed tempus urna et pharetra pharetra. Neque gravida in fermentum et sollicitudin ac.

Tortor vitae purus faucibus ornare suspendisse sed nisi lacus sed. In aliquam sem fringilla ut morbi tincidunt augue interdum. Condimentum id venenatis a condimentum vitae sapien pellentesque. Velit aliquet sagittis id consectetur purus ut faucibus. Est velit egestas dui id ornare arcu odio. Id diam vel quam elementum pulvinar. Id eu nisl nunc mi. Enim facilisis gravida neque convallis a cras. Faucibus scelerisque eleifend donec pretium vulputate sapien nec sagittis aliquam. Velit scelerisque in dictum non consectetur a. Lacus vestibulum sed arcu non odio. Eros donec ac odio tempor orci. Nullam vehicula ipsum a arcu cursus vitae congue mauris. Morbi blandit cursus risus at ultrices mi tempus imperdiet nulla. Tincidunt ornare massa eget egestas purus viverra.

Diam maecenas ultricies mi eget mauris pharetra et. Cum sociis natoque penatibus et magnis dis parturient. Viverra accumsan in nisl nisi scelerisque eu ultrices vitae. Lorem sed risus ultricies tristique nulla aliquet enim. Pellentesque dignissim enim sit amet venenatis urna cursus. Arcu vitae elementum curabitur vitae nunc sed velit dignissim. Quisque id diam vel quam. Viverra nibh cras pulvinar mattis nunc sed blandit libero volutpat. Volutpat ac tincidunt vitae semper quis lectus nulla at. At erat pellentesque adipiscing commodo. Enim nunc faucibus a pellentesque sit amet. Sit amet mauris commodo quis. Donec ultrices tincidunt arcu non sodales neque sodales ut etiam. Est pellentesque elit ullamcorper dignissim cras. Consequat semper viverra nam libero justo laoreet sit amet. Orci ac auctor augue mauris. Et netus et malesuada fames ac turpis egestas. Nunc id cursus metus aliquam eleifend mi. At risus viverra adipiscing at in.

Sed adipiscing diam donec adipiscing tristique risus nec feugiat. Nunc congue nisi vitae suscipit tellus mauris a diam. Justo laoreet sit amet cursus sit amet. Tellus integer feugiat scelerisque varius morbi enim nunc faucibus. Lorem dolor sed viverra ipsum nunc aliquet bibendum enim. Vitae suscipit tellus mauris a diam maecenas sed enim ut. Ullamcorper velit sed ullamcorper morbi. Non arcu risus quis varius quam. Laoreet sit amet cursus sit amet dictum sit amet. Nascetur ridiculus mus mauris vitae ultricies. Rutrum quisque non tellus orci ac auctor augue. Nulla malesuada pellentesque elit eget gravida cum sociis natoque. Egestas egestas fringilla phasellus faucibus. Eget egestas purus viverra accumsan in nisl nisi. Ullamcorper sit amet risus nullam eget felis. Ultrices tincidunt arcu non sodales neque sodales ut.

Duis at tellus at urna condimentum mattis pellentesque id. Massa sapien faucibus et molestie ac feugiat. Amet venenatis urna cursus eget nunc scelerisque viverra mauris. Auctor elit sed vulputate mi sit amet mauris. Odio aenean sed adipiscing diam donec adipiscing. Natoque penatibus et magnis dis parturient montes. Augue mauris augue neque gravida in fermentum et sollicitudin. Urna id volutpat lacus laoreet non. Feugiat pretium nibh ipsum consequat nisl vel. Donec et odio pellentesque diam volutpat commodo sed egestas. Scelerisque fermentum dui faucibus in ornare quam viverra orci. Quam viverra orci sagittis eu volutpat. Mauris a diam maecenas sed enim ut sem viverra aliquet. Sed turpis tincidunt id aliquet risus feugiat in.

Felis eget nunc lobortis mattis aliquam faucibus. Quisque non tellus orci ac auctor augue mauris augue neque. Ornare lectus sit amet est placerat in egestas. Sed felis eget velit aliquet. Sit amet facilisis magna etiam tempor orci. Massa sed elementum tempus egestas. Vulputate sapien nec sagittis aliquam malesuada bibendum arcu. Neque convallis a cras semper auctor neque vitae tempus. Sollicitudin ac orci phasellus egestas. Pulvinar elementum integer enim neque volutpat ac. Vulputate odio ut enim blandit volutpat maecenas volutpat. Varius duis at consectetur lorem donec massa. Eu tincidunt tortor aliquam nulla facilisi cras. Suscipit adipiscing bibendum est ultricies integer. A iaculis at erat pellentesque. Facilisi cras fermentum odio eu feugiat pretium nibh.

Ornare massa eget egestas purus viverra. Faucibus nisl tincidunt eget nullam non. Pellentesque habitant morbi tristique senectus et netus et malesuada. Lacus viverra vitae congue eu consequat ac. Tellus cras adipiscing enim eu turpis egestas pretium aenean pharetra. Vitae congue mauris rhoncus aenean vel elit scelerisque. Ut tristique et egestas quis ipsum suspendisse. Tellus cras adipiscing enim eu turpis egestas pretium aenean. Elementum nisi quis eleifend quam adipiscing vitae proin sagittis. Quis imperdiet massa tincidunt nunc pulvinar. Augue neque gravida in fermentum et sollicitudin. Quis blandit turpis cursus in hac habitasse platea dictumst. Accumsan in nisl nisi scelerisque eu ultrices vitae. Elementum nisi quis eleifend quam adipiscing vitae. At consectetur lorem donec massa sapien faucibus et molestie ac.

Elementum integer enim neque volutpat ac tincidunt vitae semper quis. Enim ut sem viverra aliquet eget sit amet tellus cras. Ultrices eros in cursus turpis massa tincidunt dui. Placerat duis ultricies lacus sed turpis. Non nisi est sit amet facilisis magna etiam tempor orci. Est velit egestas dui id. Suscipit adipiscing bibendum est ultricies integer quis. Auctor augue mauris augue neque gravida in fermentum et. Bibendum est ultricies integer quis auctor elit. Dolor sit amet consectetur adipiscing elit. Fames ac turpis egestas sed tempus urna et pharetra.

Nisl nunc mi ipsum faucibus. Eget magna fermentum iaculis eu non diam. Nisl condimentum id venenatis a. Cras adipiscing enim eu turpis egestas pretium. Sed turpis tincidunt id aliquet risus feugiat in ante. Mattis vulputate enim nulla aliquet porttitor lacus luctus accumsan. Vulputate enim nulla aliquet porttitor lacus luctus accumsan tortor posuere. Convallis aenean et tortor at risus viverra. Lobortis mattis aliquam faucibus purus in. Pulvinar neque laoreet suspendisse interdum. Id cursus metus aliquam eleifend.

Quisque egestas diam in arcu cursus. Accumsan tortor posuere ac ut. Risus viverra adipiscing at in tellus integer feugiat. Nisi porta lorem mollis aliquam ut. Purus semper eget duis at. Nulla aliquet porttitor lacus luctus accumsan tortor. Cras adipiscing enim eu turpis egestas pretium. Mattis enim ut tellus elementum sagittis vitae et leo. Blandit turpis cursus in hac habitasse. Amet consectetur adipiscing elit pellentesque habitant morbi tristique. In nisl nisi scelerisque eu ultrices vitae auctor.

Orci nulla pellentesque dignissim enim sit amet venenatis. Amet luctus venenatis lectus magna fringilla urna porttitor. Eget egestas purus viverra accumsan in. Felis bibendum ut tristique et. Eget aliquet nibh praesent tristique. Volutpat lacus laoreet non curabitur gravida arcu. At consectetur lorem donec massa sapien. Morbi quis commodo odio aenean sed adipiscing. Magna eget est lorem ipsum dolor sit amet. Ipsum dolor sit amet consectetur adipiscing elit pellentesque habitant morbi. Mattis pellentesque id nibh tortor id aliquet lectus.

Vel facilisis volutpat est velit egestas dui id. Morbi tristique senectus et netus et malesuada fames. At consectetur lorem donec massa sapien faucibus. Aliquet eget sit amet tellus cras adipiscing. Tellus cras adipiscing enim eu turpis egestas pretium aenean pharetra. Non diam phasellus vestibulum lorem sed risus ultricies tristique. Hac habitasse platea dictumst quisque sagittis. Aliquam sem et tortor consequat id porta nibh venenatis cras. Vitae tempus quam pellentesque nec nam aliquam. Amet nulla facilisi morbi tempus iaculis. At urna condimentum mattis pellentesque id nibh tortor id aliquet. Diam ut venenatis tellus in metus vulputate.

Sit amet aliquam id diam maecenas ultricies mi eget. Consectetur adipiscing elit pellentesque habitant morbi tristique senectus et. Eu feugiat pretium nibh ipsum consequat nisl. Vitae et leo duis ut diam. Nec ultrices dui sapien eget mi. Eu feugiat pretium nibh ipsum consequat nisl vel pretium lectus. Duis at consectetur lorem donec massa. Tortor consequat id porta nibh venenatis cras sed felis. Tortor at auctor urna nunc id cursus metus aliquam. Nec dui nunc mattis enim ut tellus. Venenatis lectus magna fringilla urna porttitor. Ac feugiat sed lectus vestibulum. Lorem ipsum dolor sit amet consectetur adipiscing. Est ultricies integer quis auctor elit. Aenean sed adipiscing diam donec adipiscing tristique. Id cursus metus aliquam eleifend mi in nulla. Mi eget mauris pharetra et ultrices neque. Ante metus dictum at tempor commodo."""

    # Split the Lorem Ipsum text into lines
    lines = lorem_ipsum.split(".")[:num_lines]
    
    # Write the lines to the output file
    try:
        with open(filename, "w") as f:
            f.write(".".join(lines))
        print("{}{}CREATED: Lorem Impsum file '{}' created{}".format(
            colors.BOLD,
            colors.OKGREEN,
            filename,
            colors.ENDC
        ))
    except:
        print("{}{}ERROR: Creating Lorem Impsum file '{}'!{}".format(
            colors.BOLD,
            colors.OKGREEN,
            filename,
            colors.ENDC
        ))     
